:py:mod:`piel.config`
=====================

.. py:module:: piel.config

.. autoapi-nested-parse::

   We create a set of parameters that can be used throughout the project for optimisation.



Module Contents
---------------

.. py:data:: numerical_solver



.. py:data:: nso
